Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(884)

Unified Diff: pkg/compiler/lib/src/universe/world_builder.dart

Issue 2625713002: Rename Enqueuer.universe to worldBuilder. (Closed)
Patch Set: Updated cf. comments Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/compiler/lib/src/ssa/optimize.dart ('k') | pkg/compiler/lib/src/world.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/compiler/lib/src/universe/world_builder.dart
diff --git a/pkg/compiler/lib/src/universe/world_builder.dart b/pkg/compiler/lib/src/universe/world_builder.dart
index 651d62a2160bcd09e0b1eab609192e355f31a97a..8302d84d2a5b93fcf85f8ecc7cb66f1fac8ca86e 100644
--- a/pkg/compiler/lib/src/universe/world_builder.dart
+++ b/pkg/compiler/lib/src/universe/world_builder.dart
@@ -159,8 +159,8 @@ abstract class WorldBuilder {
/// All types that are checked either through is, as or checked mode checks.
Iterable<ResolutionDartType> get isChecks;
/// Registers that [type] is checked in this universe. The unaliased type is
/// returned.
ResolutionDartType registerIsCheck(ResolutionDartType type);
/// All directly instantiated types, that is, the types of the directly
@@ -1069,7 +1069,7 @@ class ResolutionWorldBuilderImpl implements ResolutionWorldBuilder {
return _closedWorldCache = new ClosedWorldImpl(
backend: _backend,
commonElements: commonElements,
- resolverWorld: this,
+ resolutionWorldBuilder: this,
functionSetBuilder: _allFunctions,
allTypedefs: _allTypedefs,
mixinUses: _mixinUses,
@@ -159,8 +159,8 @@ abstract class WorldBuilder {
/// All types that are checked either through is, as or checked mode checks.
Iterable<ResolutionDartType> get isChecks;
- /// Registers that [type] is checked in this universe. The unaliased type is
- /// returned.
+ /// Registers that [type] is checked in this world builder. The unaliased type
+ /// is returned.
ResolutionDartType registerIsCheck(ResolutionDartType type);
/// All directly instantiated types, that is, the types of the directly
« no previous file with comments | « pkg/compiler/lib/src/ssa/optimize.dart ('k') | pkg/compiler/lib/src/world.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698